@@ -156,6 +156,10 @@ class Robot:
     def jacobian(self, fk, th):
         return jac.calc_jacobian(self.desired_frame, fk, th)
 
+    def compute_pose_error(self, target, result):
+        error = np.linalg.norm(np.dot(result, np.linalg.inv(target)) - np.mat(np.eye(4)))
+        return error
+        
     @logging_time
     def set_geomtry(self, fk, visible=False):
         self.geo = Geometry(robot=self, fk=fk)
