@@ -68,7 +68,7 @@ def plot_basis(robot=None, ax=None):
             c=directions_colors[2], label="Z")
 
 @logging_time
-def plot_robot(robot, fk, ax, name=None, visible_collision=True, visible_mesh=False, mesh_path='../asset/urdf/baxter/'):
+def plot_robot(robot, fk, ax, name=None, visible_collision=False, visible_mesh=False, mesh_path='../asset/urdf/baxter/'):
 
     if name is not None:
         name = os.path.splitext(os.path.basename(name))[0].strip()
